loader

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 27, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package loader provides functions for loading the shared whisper.cpp libraries.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetLibraryFilename

func GetLibraryFilename(path, lib string) string

GetLibraryFilename returns the full path to the library file for the given path and library name. The library name should be the "short name" (e.g., "whisper", "ggml", "ggml-cpu"). The function returns the appropriate filename based on the current OS:

  • Linux/FreeBSD: lib<name>.so
  • Windows: <name>.dll
  • Darwin: lib<name>.dylib

func LoadLibrary

func LoadLibrary(path, lib string) (ffi.Lib, error)

LoadLibrary loads a whisper.cpp shared library by short name. The path can be an empty string to use the location set by the BUCKY_LIB env variable. The lib should be the "short name" for the library, for example: whisper, ggml, ggml-base, ggml-cpu.

Types

This section is empty.

Jump to