utils

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 27, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Overview

Package utils provides small string conversion helpers used by the bucky FFI bindings. It mirrors yzma's pkg/utils so callers do not need to depend on golang.org/x/sys directly.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BytePtrFromString

func BytePtrFromString(s string) (*byte, error)

BytePtrFromString converts a Go string to a C-style null-terminated byte pointer.

func BytePtrToString

func BytePtrToString(p *byte) string

BytePtrToString converts a C-style null-terminated byte pointer to a Go string.

Types

This section is empty.

Jump to